@@ -19,7 +19,8 @@ def parse_name(s: Shop, selector: parsel.Selector = None):
 
 
 def parse_address(s: Shop, selector: parsel.Selector = None):
-    address = selector.xpath("string(//span[contains(text(), 'Business Address')]/following-sibling::ul)").get()
+    address = selector.xpath("//span[contains(text(), 'Business Address')]/following-sibling::ul/li//text()").getall()
+    address = " ".join(address)
     if address == "":
         s.address = None
     else:
